@@ -14,17 +14,17 @@ module Utils (
   )
 where
 import Codec.Binary.UTF8.String as UTF8 (decodeString, encodeString, isUTF8Encoded)
-import Control.Concurrent
+import Control.Concurrent.MSampleVar
 import Control.Monad
 import Data.List
 import Data.Maybe
 import Data.Time.Clock (UTCTime,getCurrentTime)
-import Data.Time.Format (parseTime)
+import Data.Time.Format (parseTimeM)
 import Data.Time.LocalTime (LocalTime,getCurrentTimeZone,utcToLocalTime)
 import Prelude hiding (log)
 import System.Info
 import System.IO (stdout,hFlush)
-import System.Locale (defaultTimeLocale)
+import Data.Time.Format (defaultTimeLocale)
 import Text.Feed.Query
 import Text.Feed.Types (Item)
 import Text.ParserCombinators.Parsec hiding (label)
@@ -50,19 +50,19 @@ tracewith f e = trace (f e) e
 
 -- Light abstraction layer for thread-safe mutable data
 
-type Shared a = SampleVar a
+type Shared a = MSampleVar a
 
-newSharedVar :: a -> IO (SampleVar a)
-newSharedVar = newSampleVar
+newSharedVar :: a -> IO (MSampleVar a)
+newSharedVar = newSV
 
-getSharedVar :: SampleVar a -> IO a
+getSharedVar :: MSampleVar a -> IO a
 getSharedVar v = do
-  x <- readSampleVar v
-  writeSampleVar v x
+  x <- readSV v
+  writeSV v x
   return x
 
-putSharedVar :: SampleVar a -> a -> IO ()
-putSharedVar v x = writeSampleVar v x
+putSharedVar :: MSampleVar a -> a -> IO ()
+putSharedVar v x = writeSV v x
 
 -- Option parsing helpers
 
@@ -211,7 +211,7 @@ decrementMaybe = maybe Nothing (Just . pred)
 -- | Parse a datetime string if possible, trying at least the formats
 -- likely to be used in RSS/Atom feeds.
 parseDateTime :: String -> Maybe UTCTime
-parseDateTime s = firstJust [parseTime defaultTimeLocale f s' | f <- formats]
+parseDateTime s = firstJust [parseTimeM True defaultTimeLocale f s' | f <- formats]
     where
       s' = adaptForParseTime s
       adaptForParseTime = gsubRegexPR "(....-..-..T..:..:..[\\+\\-]..):(..)" "\\1\\2" -- 2009-09-22T13:10:56+00:00
@@ -268,10 +268,10 @@ strip, lstrip, rstrip, dropws :: String -> String
 strip = lstrip . rstrip
 lstrip = dropws
 rstrip = reverse . dropws . reverse
-dropws = dropWhile (`elem` " \t")
+dropws = dropWhile (`elem` (" \t"::String))
 
 chomp :: String -> String
-chomp = reverse . dropWhile (`elem` "\n\r") . reverse
+chomp = reverse . dropWhile (`elem` ("\n\r"::String)) . reverse
 
 isLeft :: Either a b -> Bool
 isLeft (Left _) = True
