@@ -12,6 +12,7 @@ License: BSD3.
 module Main where
 
 import Control.Concurrent
+import Control.Concurrent.STM
 import Control.Exception
 import Control.Monad (when,unless)
 import Data.Maybe
@@ -40,7 +41,7 @@ getRss2IrcArgs = do
       opterror "--interval 0 requires --num-iterations 10 or less"
     seq (applyReplacements opts "") $ return () -- report any bad --replace regexp
     return opts
-  q <- newChan
+  q <- atomically $ newTChan
   t <- getCurrentTime
   let reader = Reader{httpManager=Nothing
                      ,iterationsleft=num_iterations opts
